@@ -8,7 +8,7 @@ from collections import defaultdict
 from openpyxl import load_workbook
 from xlrd import open_workbook
 
-__version__ = "0.4.0"
+__version__ = "0.4.1"
 
 if sys.platform != "win32":
     import signal
@@ -88,7 +88,7 @@ def get_view(file, limit: int, nlines: int):
                 width.append(len(string))
             width[index] = min(limit, max(len(string), width[index]))
         rows.append(row)
-        if i == nlines:
+        if nlines and i == nlines:
             break
     for row in rows:
         out_row = []
@@ -149,7 +149,7 @@ def get_file(file):
         file = sys.stdin
     else:
         if file.endswith(".xlsx"):
-            wb = load_workbook(file, read_only=True)
+            wb = load_workbook(file, read_only=True, data_only=True)
             ws = wb.active
             file = ("\t".join([str(_.value) for _ in row]) for row in ws.rows)
         elif file.endswith(".xls"):
@@ -173,7 +173,7 @@ def main():
     parser.add_argument("-p", "--pattern", type=str, help="pattern to match, wrap in single quotes")
     parser.add_argument("-a", "--add", type=str, help="add a new column with pattern, wrap in single quotes")
     parser.add_argument("-r", "--reorder", type=str, help="reorder columns, comma separated list of column numbers")
-    parser.add_argument("-l", "--limit", type=int, default=100, help="limit of column width, used with -v, default: 100")
+    parser.add_argument("-l", "--limit", type=int, default=100, help="limit of column width, used with -v, 0 for unlimited, default: 100")
     parser.add_argument("-n", "--nlines", type=int, default=100, help="max number of lines to view, used with -v, default: 100")
     parser.add_argument("-c", "--column", type=int, default=0, help="column number to stat, used with -s, default: 0, means all columns")
     parser.add_argument("-V", "--version", action="version", version=__version__)
